@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2008, 2009, 2010, 2012, 2016, 2017 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2008-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
 
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
@@ -19,7 +19,7 @@
 
 class KGpgGroupNodePrivate {
 public:
-	KGpgGroupNodePrivate(const QString &name);
+	explicit KGpgGroupNodePrivate(const QString &name);
 
 	QString m_name;
 
