@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2009, 2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2009-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -14,10 +14,6 @@ KGpgKeyserverGetTransaction::KGpgKeyserverGetTransaction(QObject *parent, const
 	setKeyIds(keys);
 }
 
-KGpgKeyserverGetTransaction::~KGpgKeyserverGetTransaction()
-{
-}
-
 bool
 KGpgKeyserverGetTransaction::preStart()
 {
@@ -64,10 +60,6 @@ KGpgReceiveKeys::KGpgReceiveKeys(QObject *parent, const QString &keyserver, cons
 {
 }
 
-KGpgReceiveKeys::~KGpgReceiveKeys()
-{
-}
-
 QString
 KGpgReceiveKeys::getGpgCommand() const
 {
@@ -79,10 +71,6 @@ KGpgRefreshKeys::KGpgRefreshKeys(QObject *parent, const QString &keyserver, cons
 {
 }
 
-KGpgRefreshKeys::~KGpgRefreshKeys()
-{
-}
-
 QString
 KGpgRefreshKeys::getGpgCommand() const
 {
